PAWpySeed: /home/kyle/Research/projects/pawpyseed/pawpyseed/core/reader.h Source File

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- File List
- File Members

reader.h
Go to the documentation of this file.
1
9 #ifndef READER_H
10 #define READER_H
11 #include "utils.h"
12
16 void setup(char* filename, int* pnrecl, int* pnspin, int* pnwk, int* pnband,
17 double* nb1, double* nb2, double* nb3, double* ecut,
18 double* lattice, double* reclattice);
19
25 pswf_t* read_wavefunctions(char* filename, double* kpt_weights);
26
30 kpoint_t** read_one_band(int* G_bounds, double* kpt_weights, int* ns, int* nk, int* nb, int BAND_NUM, char* filename);
31
32 #endif
33
kpoint
Definition: utils.h:99
utils.h
read_one_band
kpoint_t ** read_one_band(int *G_bounds, double *kpt_weights, int *ns, int *nk, int *nb, int BAND_NUM, char *filename)
pswf
Definition: utils.h:110
setup
void setup(char *filename, int *pnrecl, int *pnspin, int *pnwk, int *pnband, double *nb1, double *nb2, double *nb3, double *ecut, double *lattice, double *reclattice)
read_wavefunctions
pswf_t * read_wavefunctions(char *filename, double *kpt_weights)